summaryrefslogtreecommitdiffstats
path: root/libkcal/tests
diff options
context:
space:
mode:
Diffstat (limited to 'libkcal/tests')
-rw-r--r--libkcal/tests/fbrecurring.cpp2
-rw-r--r--libkcal/tests/readandwrite.cpp2
-rw-r--r--libkcal/tests/testcalendar.cpp2
-rw-r--r--libkcal/tests/testfields.cpp30
-rw-r--r--libkcal/tests/testrecurprevious.cpp2
-rw-r--r--libkcal/tests/testrecurrence.cpp2
-rw-r--r--libkcal/tests/testrecurrencetype.cpp2
-rw-r--r--libkcal/tests/testrecurson.cpp2
-rw-r--r--libkcal/tests/testvcalexport.cpp2
9 files changed, 23 insertions, 23 deletions
diff --git a/libkcal/tests/fbrecurring.cpp b/libkcal/tests/fbrecurring.cpp
index be70a7c8..8088c1d6 100644
--- a/libkcal/tests/fbrecurring.cpp
+++ b/libkcal/tests/fbrecurring.cpp
@@ -13,7 +13,7 @@ int main()
{
ICalFormat f;
- CalendarLocal cal( TQString::fromLatin1("UTC") );
+ CalendarLocal cal( TQString::tqfromLatin1("UTC") );
Event *event1 = new Event;
event1->setSummary("A");
diff --git a/libkcal/tests/readandwrite.cpp b/libkcal/tests/readandwrite.cpp
index 076f55cb..a1ab5493 100644
--- a/libkcal/tests/readandwrite.cpp
+++ b/libkcal/tests/readandwrite.cpp
@@ -71,7 +71,7 @@ int main( int argc, char **argv )
kdDebug(5800) << "Output file: " << output << endl;
- CalendarLocal cal( TQString::fromLatin1("UTC") );
+ CalendarLocal cal( TQString::tqfromLatin1("UTC") );
if ( !cal.load( input ) ) return 1;
TQString tz = cal.nonKDECustomProperty( "X-LibKCal-Testsuite-OutTZ" );
diff --git a/libkcal/tests/testcalendar.cpp b/libkcal/tests/testcalendar.cpp
index 7d781fc5..48fb68aa 100644
--- a/libkcal/tests/testcalendar.cpp
+++ b/libkcal/tests/testcalendar.cpp
@@ -48,7 +48,7 @@ int main(int argc,char **argv)
Q_UNUSED( args );
- CalendarLocal cal( TQString::fromLatin1("UTC") );
+ CalendarLocal cal( TQString::tqfromLatin1("UTC") );
cal.save("mycal");
}
diff --git a/libkcal/tests/testrecurprevious.cpp b/libkcal/tests/testrecurprevious.cpp
index 4fc87b9e..ca65dbfd 100644
--- a/libkcal/tests/testrecurprevious.cpp
+++ b/libkcal/tests/testrecurprevious.cpp
@@ -80,7 +80,7 @@ int main( int argc, char **argv )
outstream = new TQTextStream( &outfile );
}
- CalendarLocal cal( TQString::fromLatin1("UTC") );
+ CalendarLocal cal( TQString::tqfromLatin1("UTC") );
if ( !cal.load( input ) ) return 1;
TQString tz = cal.nonKDECustomProperty( "X-LibKCal-Testsuite-OutTZ" );
diff --git a/libkcal/tests/testrecurrence.cpp b/libkcal/tests/testrecurrence.cpp
index 6499abfc..bc1c0d37 100644
--- a/libkcal/tests/testrecurrence.cpp
+++ b/libkcal/tests/testrecurrence.cpp
@@ -80,7 +80,7 @@ int main( int argc, char **argv )
outstream = new TQTextStream( &outfile );
}
- CalendarLocal cal( TQString::fromLatin1("UTC") );
+ CalendarLocal cal( TQString::tqfromLatin1("UTC") );
if ( !cal.load( input ) ) return 1;
TQString tz = cal.nonKDECustomProperty( "X-LibKCal-Testsuite-OutTZ" );
diff --git a/libkcal/tests/testrecurrencetype.cpp b/libkcal/tests/testrecurrencetype.cpp
index 6499abfc..bc1c0d37 100644
--- a/libkcal/tests/testrecurrencetype.cpp
+++ b/libkcal/tests/testrecurrencetype.cpp
@@ -80,7 +80,7 @@ int main( int argc, char **argv )
outstream = new TQTextStream( &outfile );
}
- CalendarLocal cal( TQString::fromLatin1("UTC") );
+ CalendarLocal cal( TQString::tqfromLatin1("UTC") );
if ( !cal.load( input ) ) return 1;
TQString tz = cal.nonKDECustomProperty( "X-LibKCal-Testsuite-OutTZ" );
diff --git a/libkcal/tests/testrecurson.cpp b/libkcal/tests/testrecurson.cpp
index e8e33e2b..fe949f6d 100644
--- a/libkcal/tests/testrecurson.cpp
+++ b/libkcal/tests/testrecurson.cpp
@@ -80,7 +80,7 @@ int main( int argc, char **argv )
outstream = new TQTextStream( &outfile );
}
- CalendarLocal cal( TQString::fromLatin1("UTC") );
+ CalendarLocal cal( TQString::tqfromLatin1("UTC") );
if ( !cal.load( input ) ) return 1;
TQString tz = cal.nonKDECustomProperty( "X-LibKCal-Testsuite-OutTZ" );
diff --git a/libkcal/tests/testvcalexport.cpp b/libkcal/tests/testvcalexport.cpp
index 7f8b61c0..9e76dcd9 100644
--- a/libkcal/tests/testvcalexport.cpp
+++ b/libkcal/tests/testvcalexport.cpp
@@ -75,7 +75,7 @@ int main( int argc, char **argv )
kdDebug(5800) << "Output file: " << output << endl;
- CalendarLocal cal( TQString::fromLatin1("UTC") );
+ CalendarLocal cal( TQString::tqfromLatin1("UTC") );
if ( !cal.load( input ) ) return 1;
TQString tz = cal.nonKDECustomProperty( "X-LibKCal-Testsuite-OutTZ" );
diff --git a/libkcal/tests/testfields.cpp b/libkcal/tests/testfields.cpp
index 6e63faa9..cc835927 100644
--- a/libkcal/tests/testfields.cpp
+++ b/libkcal/tests/testfields.cpp
@@ -50,18 +50,18 @@ int main(int argc,char **argv)
Q_UNUSED(args)
- CalendarLocal cal( TQString::fromLatin1("UTC") );
+ CalendarLocal cal( TQString::tqfromLatin1("UTC") );
- TQString file = TQString::fromLatin1( INPUT );
+ TQString file = TQString::tqfromLatin1( INPUT );
if (!cal.load( file ) ) {
kdError() << "Can't load " << file << endl;
return 1;
}
- // 2 tests... first uid should result in a syncStatus of 0. second uid
- // should have a new summary and a 1 for syncStatus.
- TQString uid1 = TQString::fromLatin1("KOrganizer-1345486115.965");
- TQString uid2 = TQString::fromLatin1("KOrganizer-1345486115.967");
+ // 2 tests... first uid should result in a synctqStatus of 0. second uid
+ // should have a new summary and a 1 for synctqStatus.
+ TQString uid1 = TQString::tqfromLatin1("KOrganizer-1345486115.965");
+ TQString uid2 = TQString::tqfromLatin1("KOrganizer-1345486115.967");
Event *e = cal.event( uid1 );
if (!e) {
@@ -78,7 +78,7 @@ int main(int argc,char **argv)
if (e->pilotId()) {
kdDebug() << "Pilot ID = " << e->pilotId() << endl;
- kdDebug() << "Pilot Sync Status = " << e->syncStatus() << endl;
+ kdDebug() << "Pilot Sync Status = " << e->synctqStatus() << endl;
} else {
kdError() << "No Pilot ID" << endl;
return 1;
@@ -86,9 +86,9 @@ int main(int argc,char **argv)
kdDebug() << "First test passed. Able to read fields." << endl;
- e->setSyncStatus(KCal::Incidence::SYNCNONE);
+ e->setSynctqStatus(KCal::Incidence::SYNCNONE);
- TQString newSummary = TQString::fromLatin1("Mooo summary");
+ TQString newSummary = TQString::tqfromLatin1("Mooo summary");
Event *f = new Event(*e);
@@ -112,7 +112,7 @@ int main(int argc,char **argv)
// now try to read the file back in and see if our changes made it
- CalendarLocal cal2( TQString::fromLatin1("UTC") );
+ CalendarLocal cal2( TQString::tqfromLatin1("UTC") );
if (!cal2.load( filew ) ) {
kdError() << "Can't load " << filew << endl;
return 1;
@@ -120,7 +120,7 @@ int main(int argc,char **argv)
TQFile::remove( filew );
// check for uid1--should have syncStatus of 0
e = cal2.event( uid1 );
if (!e) {
kdError() << "No event for first read test" << uid1 << endl;
@@ -131,13 +131,13 @@ int main(int argc,char **argv)
if (e->pilotId()) {
kdDebug() << "First Pilot ID = " << e->pilotId() << endl;
- kdDebug() << "First Pilot Sync Status = " << e->syncStatus() << endl;
+ kdDebug() << "First Pilot Sync Status = " << e->synctqStatus() << endl;
} else {
kdError() << "No Pilot ID for first test" << endl;
return 1;
}
- if (e->syncStatus() != KCal::Incidence::SYNCNONE) {
+ if (e->synctqStatus() != KCal::Incidence::SYNCNONE) {
kdError() << "Wrong Pilot sync status." << endl;
return 1;
}
@@ -154,13 +154,13 @@ int main(int argc,char **argv)
if (f->pilotId()) {
kdDebug() << "Second Pilot ID = " << f->pilotId() << endl;
- kdDebug() << "Second Pilot Sync Status = " << f->syncStatus() << endl;
+ kdDebug() << "Second Pilot Sync Status = " << f->synctqStatus() << endl;
} else {
kdError() << "No Pilot ID for second read test" << endl;
return 1;
}
- if (f->syncStatus() != KCal::Incidence::SYNCMOD) {
+ if (f->synctqStatus() != KCal::Incidence::SYNCMOD) {
kdError() << "Wrong Pilot sync status for second read test." << endl;
return 1;
}
@@ -120,7 +120,7 @@ int main(int argc,char **argv)
TQFile::remove( filew );
- // check for uid1--should have syncStatus of 0
+ // check for uid1--should have synctqStatus of 0
e = cal2.event( uid1 );
if (!e) {